@@ -45,29 +45,30 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "aac-types_8h.html",
-"group__pw__core.html#gae40b2a9bf4e42aac082bf90e37389c02",
-"group__pw__impl__node.html#gaa15ac6102a1e30bfcb3b8b6c4a2fbb2f",
-"group__pw__log.html",
-"group__pw__port.html#ga95a863ccc61e0293ae494345bbd51e19",
-"group__pw__session__manager.html#ga7942053dc37f4422c4342845b98013ca",
-"group__spa__ansi.html#gad05b2989634f1bdd58adce5724527574",
-"group__spa__device.html#ga5fc03e022b6b34a95c40b992b46210b3",
-"group__spa__keys.html#gadf50fc8fd87773ea21c53db357e38ae6",
-"group__spa__node.html#ga784ec374e7b19204bec41fffca6a1abd",
-"group__spa__param.html#ga67fd4b04ffeaa78409011c770e97e2f2",
-"group__spa__param.html#gga339d759aafadca6ef623f32ce7e65be0a8944822c83a3f771fb66f31d37fdb252",
-"group__spa__param.html#gga906301de4445d3723667b393c6006202aed107ec36acfb32eda22a789fa5bcdbe",
-"group__spa__param.html#ggad7758d1c91573ef57ebf61ac113bb43ea6d99d19d1d6a03a3acf1b643450e413d",
-"group__spa__pod.html#ga978ad0926ea7b81d8f4e9ebf4208a037",
-"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a73849a477ad593eabbd5c08bec295d84",
-"page_man_pw-mon_1.html",
-"structpw__client__endpoint__events.html#a43e06e14ba4461922bfce4c3c98c13f1",
-"structpw__impl__factory__events.html",
-"structpw__protocol__native__message.html#abaad1bc5e0c163fa89fea9c0d0852c4f",
-"structspa__dbus__connection__events.html#a2ae8b95b36226127853160f1779260e0",
-"structspa__log__topic.html#ab77cbaf7b01d2f4dddbcf7f51766b9d6",
-"structspa__process__latency__info.html"
+"group__pw__core.html#gaab5fd68faa350ca3f2928032b0553a3f",
+"group__pw__impl__module.html#gad0e64478bc2c8627547647a8fd689fe9",
+"group__pw__link.html#ga5d3c859845886244df9d51621460f53b",
+"group__pw__pipewire.html#gaf3d7686492ea5032eb135cddf21d3da2",
+"group__pw__session__manager.html#ga659e95476b1273ad6b2d247256375df7",
+"group__spa__ansi.html#ga5d126113edfe9df70eb7f68a6f874c85",
+"group__spa__debug.html#gad05de600014e815c9aadc8de416cbe06",
+"group__spa__json.html#gab73d06c52e118fb6ff1694e2ca423cb1",
+"group__spa__names.html#gac4ef8bddd1f53a3a890c5ab7bb32db3f",
+"group__spa__param.html#ga33238198e192056d4aba1b75fb7c5828",
+"group__spa__param.html#gae80e1e14b3317a337ea5ac70f6c2c9f4",
+"group__spa__param.html#gga4077adc9cb334bd78d561f96c04eebbcaf3305fb7d954386c02364e9fbb98e5cd",
+"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaa2cc5175abd3f6648bb173a3637744b2b",
+"group__spa__pod.html#ga2fb7171ab4bf8b85b835c8ac66cc3a26",
+"group__spa__ringbuffer.html#gad620fa22ac4d12b7f482e50525e1242f",
+"iec958_8h.html",
+"page_pulse_module_zeroconf_discover.html",
+"structpw__device__info.html",
+"structpw__memblock.html#a8fb4076dc9a00af2a3da6be6859b6a00",
+"structspa__audio__aec__methods.html#aadf3db584c3062de5a2af134e6d7014d",
+"structspa__graph__node.html#acfb4e7658140701927336dee05ed1948",
+"structspa__node__info.html",
+"structspa__type__info.html"
 ];
 
-var SYNCONMSG = 'click to disable panel synchronisation';
-var SYNCOFFMSG = 'click to enable panel synchronisation';
\ No newline at end of file
+var SYNCONMSG = 'click to disable panel synchronization';
+var SYNCOFFMSG = 'click to enable panel synchronization';
\ No newline at end of file
